# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['pyexcel_export']

package_data = \
{'': ['*']}

install_requires = \
['importlib_resources>=1.0,<2.0',
 'openpyxl>=2.5,<3.0',
 'oyaml>=0.5.0,<0.6.0',
 'pyexcel-xlsx>=0.5.6,<0.6.0',
 'pyexcel>=0.5.8,<0.6.0']

setup_kwargs = {
    'name': 'pyexcel-export',
    'version': '0.3.3',
    'description': 'Keep good formatting when exporting to *.xlsx, *.yaml and *.json and when updating data.',
    'long_description': '# pyexcel-export - Keep optimal formatting when exported to xlsx format\n\n[![Build Status](https://travis-ci.org/patarapolw/pyexcel-export.svg?branch=master)](https://travis-ci.org/patarapolw/pyexcel-export)\n[![Build status](https://ci.appveyor.com/api/projects/status/wwg0b41pxaw586xr?svg=true)](https://ci.appveyor.com/project/patarapolw/pyexcel-export)\n[![PyPI version shields.io](https://img.shields.io/pypi/v/pyexcel_export.svg)](https://pypi.python.org/pypi/pyexcel_export/)\n[![PyPI license](https://img.shields.io/pypi/l/pyexcel_export.svg)](https://pypi.python.org/pypi/pyexcel_export/)\n[![PyPI pyversions](https://img.shields.io/pypi/pyversions/pyexcel_export.svg)](https://pypi.python.org/pypi/pyexcel_export/)\n\npyexcel-export is a wrapper around [pyexcel](https://github.com/pyexcel/pyexcel), [pyexcel-xlsx](https://github.com/pyexcel/pyexcel-xlsx) and [openpyxl](https://bitbucket.org/openpyxl/openpyxl) to read formatting (stylesheets) and update pre-existing files without destroying the stylesheets.\n\npyexcel-export also introduces two new exporting format, `*.yaml` and `*.pyexcel.json`, which is based on [NoIndentEncoder](https://stackoverflow.com/a/25935321/9023855). This allows you to edit the spreadsheet in you favorite text editor without being frustrated by automatically collapsed cells in Excel.\n\n## Known constraints\n\nThe "stylesheets" exported from Excel is in a very long base64 encoded format when exported to `*.json` or `*.pyexcel.json`, so exporting such to `*.json` is disabled by default.\n\nAs stylesheets copying works by [`openpyxl.worksheet.copier.WorksheetCopy`](https://openpyxl.readthedocs.io/en/2.5/_modules/openpyxl/worksheet/copier.html), it may work only on values, styles, dimensions, and merged cells, but charts might not be supported.\n\n## Installation\n\nYou can install pyexcel-export via pip:\n\n```commandline\n$ pip install pyexcel-export\n```\n\nor clone it and install it.\n\n## Usage\n\nFor more documentation, see https://github.com/patarapolw/pyexcel-export/tree/master/docs\n\n### Read \\*.pyexcel.json\n\n```python\n>>> from pyexcel_export import get_data\n>>> from collections import OrderedDict\n>>> data, meta = get_data(\'test.yaml\')  # *.pyexcel.json is also possible.\n>>> data\nOrderedDict([(\'test\', [[\'id\', \'English\', \'Pinyin\', \'Hanzi\', \'Audio\', \'Tags\'], [1419644212689, \'Hello!\', \'Nǐ hǎo!\', \'你好！\', \'[sound:tmp1cctcn.mp3]\', \'\'], [1419644212690, \'What are you saying?\', \'Nǐ shuō shénme?\', \'你说什么？\', \'[sound:tmp4tzxbu.mp3]\', \'\'], [1419644212691, \'What did you do?\', \'nǐ zuò le shénme ?\', \'你做了什么？\', \'[sound:333012.mp3]\', \'\']])])\n>>> meta\nMeta([\n  (\'created\', \'2018-07-15T05:32:43.976194\'),\n  (\'modified\', \'2018-07-16T07:31:26.232350\'),\n  (\'has_header\', True),\n  (\'freeze_header\', True),\n  (\'col_width_fit_param_keys\', True),\n  (\'col_width_fit_ids\', True),\n  (\'bool_as_string\', True),\n  (\'allow_table_hiding\', True),\n  (\'_styles\', <_io.BytesIO object at 0x1065dff10>)\n])\n>>> meta.matrix\n[(\'created\', \'2018-07-15T05:32:43.976194\'), (\'modified\', \'2018-07-15T05:32:52.248192\'), (\'has_header\', True), (\'freeze_header\', True), (\'col_width_fit_param_keys\', True), (\'col_width_fit_ids\', True), (\'allow_hidden_tables\', True), (\'_styles\', {"<class \'_io.BytesIO\'>": <_io.BytesIO object at 0x1103d9048>})]\n>>> meta.excel_matrix\n[(\'created\', \'2018-07-15T05:32:43.976194\'), (\'modified\', \'2018-07-15T05:32:52.248192\'), (\'has_header\', {"<class \'bool\'>": True}), (\'freeze_header\', {"<class \'bool\'>": True}), (\'col_width_fit_param_keys\', {"<class \'bool\'>": True}), (\'col_width_fit_ids\', {"<class \'bool\'>": True}), (\'allow_hidden_tables\', {"<class \'bool\'>": True}), (\'_styles\', {"<class \'_io.BytesIO\'>": <_io.BytesIO object at 0x10b56b048>})]\n```\n\n### Exporting stylesheets\n\n```python\n>>> from pyexcel_export import get_meta\n>>> get_meta()\nMeta([\n  (\'created\', \'2018-07-15T05:32:43.976194\'),\n  (\'has_header\', True),\n  (\'freeze_header\', True),\n  (\'col_width_fit_param_keys\', True),\n  (\'col_width_fit_ids\', True),\n  (\'bool_as_string\', True),\n  (\'allow_table_hiding\', True)\n])\n>>> get_meta(\'test.xlsx\')\nMeta([\n  (\'created\', \'2018-07-15T05:32:43.976194\'),\n  (\'modified\', \'2018-07-16T07:31:26.232350\'),\n  (\'has_header\', True),\n  (\'freeze_header\', True),\n  (\'col_width_fit_param_keys\', True),\n  (\'col_width_fit_ids\', True),\n  (\'bool_as_string\', True),\n  (\'allow_table_hiding\', True),\n  (\'_styles\', <_io.BytesIO object at 0x1065dff10>)\n])\n```\n### Saving files, while preserving the formatting.\n\n```python\n>>> from pyexcel_export import get_meta, save_data\n>>> from collections import OrderedDict\n>>> meta = get_meta(\'test.xlsx\')\n>>> data = OrderedDict()\n>>> data.update({"Sheet 1": [["header A", "header B", "header C"], [1, 2, 3]]})\n>>> save_data("your_file.xlsx", data, meta=meta)\n```\n### Of course, you can use the ExcelLoader class directly\n\n```python\n>>> from pyexcel_export import ExcelLoader\n>>> loader = ExcelLoader("test.xlsx")\n>>> loader.save("test.xlsx")\n\n```\n\n### \\*.yaml format\n\n```yaml\n_meta:\n- [created, \'2018-07-15T05:32:43.976194\']\n- [modified, \'2018-07-16T07:45:53.534165\']\n- [has_header, true]\n- [freeze_header, true]\n- [col_width_fit_param_keys, true]\n- [col_width_fit_ids, true]\n- [bool_as_string, true]\n- [allow_table_hiding, true]\ntest:\n- [id, English, Pinyin, Hanzi, Audio, Tags]\n- [1419644212689, Hello!, Nǐ hǎo!, 你好！, \'[sound:tmp1cctcn.mp3]\', \'\']\n- [1419644212690, \'What are you saying?\', \'Nǐ shuō shénme?\', 你说什么？, \'[sound:tmp4tzxbu.mp3]\',\n  \'\']\n- [1419644212691, \'What did you do?\', \'nǐ zuò le shénme ?\', 你做了什么？, \'[sound:333012.mp3]\',\n  \'\']\n```\n\n### \\*.pyexcel.json format\n```json\n{\n  "_meta": [\n    ["\\"created\\"", "\\"2018-07-12T15:21:25.777499\\""],\n    ["\\"modified\\"", "\\"2018-07-15T06:59:22.707162\\""],\n    ["\\"has_header\\"", "true"],\n    ["\\"freeze_header\\"", "true"],\n    ["\\"col_width_fit_param_keys\\"", "true"],\n    ["\\"col_width_fit_ids\\"", "true"]\n  ],\n  "test": [\n    ["\\"id\\"", "\\"English\\"", "\\"Pinyin\\"", "\\"Hanzi\\"", "\\"Audio\\"", "\\"Tags\\""],\n    ["1419644212689", "\\"Hello!\\"", "\\"Nǐ hǎo!\\"", "\\"你好！\\"", "\\"[sound:tmp1cctcn.mp3]\\"", "\\"\\""],\n    ["1419644212690", "\\"What are you saying?\\"", "\\"Nǐ shuō shénme?\\"", "\\"你说什么？\\"", "\\"[sound:tmp4tzxbu.mp3]\\"", "\\"\\""],\n    ["1419644212691", "\\"What did you do?\\"", "\\"nǐ zuò le shénme ?\\"", "\\"你做了什么？\\"", "\\"[sound:333012.mp3]\\"", "\\"\\""]\n  ]\n}\n```\n\n## MIT License\n\nCopyright (c) 2018 Pacharapol Withayasakpunt\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n',
    'author': 'Pacharapol Withayasakpunt',
    'author_email': 'patarapolw@gmail.com',
    'url': 'https://github.com/patarapolw/pyexcel-export',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.5',
}


setup(**setup_kwargs)
